@@ -414,6 +414,7 @@
 #define SIGNAL_RETURN_TYPE_IS_VOID 1
 #define RETSIGTYPE void
 #define VOID_SIGHANDLER 1
+#define HAVE_SIGHANDLER_T 1
 #define STRUCT_RLIMIT struct rlimit
 
 #ifdef __APPLE__
@@ -473,7 +474,7 @@
 /* #undef HAVE_BSD_SIGNALS */
 /* #undef HAVE_SVR3_SIGNALS */
 /* #undef HAVE_V7_SIGNALS */
-
+#define HAVE_ERR_remove_thread_state 1
 
 /* #undef HAVE_SOLARIS_STYLE_GETHOST */
 
@@ -639,16 +640,16 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 1
-#define MYSQL_VERSION_PATCH 9
+#define MYSQL_VERSION_PATCH 10
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.1.9"
+#define PACKAGE_STRING "MySQL Server 10.1.10"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.1.9"
-#define VERSION "10.1.9"
+#define PACKAGE_VERSION "10.1.10"
+#define VERSION "10.1.10"
 #define PROTOCOL_VERSION 10
 
 #define MALLOC_LIBRARY "system"
